@@ -1,4 +1,4 @@
-# $Id: ODBC.pm 14960 2011-10-22 15:30:16Z mjevans $
+# $Id: ODBC.pm 15000 2011-11-15 16:09:32Z mjevans $
 #
 # Copyright (c) 1994,1995,1996,1998  Tim Bunce
 # portions Copyright (c) 1997-2004  Jeff Urlwin
@@ -19,7 +19,7 @@ require 5.008;
 # see discussion on dbi-users at
 # http://www.nntp.perl.org/group/perl.dbi.dev/2010/07/msg6096.html and
 # http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-$DBD::ODBC::VERSION = '1.32_2';
+$DBD::ODBC::VERSION = '1.32_3';
 
 {
     ## no critic (ProhibitMagicNumbers ProhibitExplicitISA)
@@ -32,7 +32,7 @@ $DBD::ODBC::VERSION = '1.32_2';
 
     @ISA = qw(Exporter DynaLoader);
 
-    # my $Revision = substr(q$Id: ODBC.pm 14960 2011-10-22 15:30:16Z mjevans $, 13,2);
+    # my $Revision = substr(q$Id: ODBC.pm 15000 2011-11-15 16:09:32Z mjevans $, 13,2);
 
     require_version DBI 1.21;
 
@@ -222,7 +222,7 @@ $DBD::ODBC::VERSION = '1.32_2';
 	# create a "blank" statement handle
 	my $sth = DBI::_new_sth($dbh, { 'Statement' => "SQLTables" });
 
-	DBD::ODBC::st::_tables($dbh,$sth, $catalog, $schema, $table, $type)
+	DBD::ODBC::st::_tables2($dbh,$sth, $catalog, $schema, $table, $type)
 	      or return;
 	return $sth;
     }
@@ -568,7 +568,7 @@ DBD::ODBC - ODBC Driver for DBI
 
 =head1 VERSION
 
-This documentation refers to DBD::ODBC version 1.32_2.
+This documentation refers to DBD::ODBC version 1.32_3.
 
 =head1 SYNOPSIS
 
@@ -1809,6 +1809,11 @@ You cannot use unicode parameter names e.g.,
 You cannot use unicode strings in calls to prepare if you set the
 odbc_execdirect attribute.
 
+You cannot pass unicode catalog, schema, table and column names into
+metadata calls (like column_info) at present because the XS interface
+uses char * instead of Perl scalars. NOTE: as of DBD::ODBC 1.32_3 Unicode
+is fully supported for input parameters in table_info.
+
 You cannot use the iODBC driver manager with DBD::ODBC built for
 unicode.
 
